////////////////////////////////////////////////////////////////////////////////
//
//  Alarm Monitoring system
//  with Radio related Code ported from:
//  WIRELESS MOUSETRAP MONITORING SYSTEM by Alberto Ricci Bitti (c) 2003
//  www.riccibitti.com
//
///////////////////////////////////////////////////////////////////////////////
//
// MODULE:   RXM_TX629_Hardw_R2.c
// PURPOSE:  Defines hardware related details, registers, timers.
//           Defines simbolic names for the pins used
// REQUIRES: No special requirements.
// NOTES:    Imported code translated from MC68HC908QT chip to PIC12F683
//
////////////////////////////////////////////////////////////////////////////////

//******************************************************************************
// Function:    ServiceTimer0Interrupt
//******************************************************************************

#int_timer0
void system_334us_timer(void)
{

// Note: the actual set_timer0 value must be corrected to allow to correct
// the time the compiler has used to save the CPU registers. This is for
// the 675 chip exactly 32 instructions (see list file location 0x004 - 0x040)
// the true load value is: (256 - 167) + 32 = 121
// the get_timer0 current value is added to correct for this problem

    set_timer0(T0_LOAD);   // Re-load timer
    //output_toggle(PDN_OUT);
    TX_FLAG = TRUE;
}


///////////////////////////////////////////////////////////////////////////////
// Hardware_initialize - performs register inizialization
///////////////////////////////////////////////////////////////////////////////


void hardware_initialize(void)
{

    //setup_oscillator(OSC_8MHZ);

    set_tris_a( PORT_A_MASK );
    set_tris_c( PORT_C_MASK );

    ANSEL  = 0b01110010;    // Input pins fonfigured for Analog: AN1, AN4, AN5, AN6

	/* Hardware startup states:

	RA5 - TXD DATA		0
	RA4 - TX  PDN		0
	RA3 - SW1 INP		0
	RA2	- SW2 INP		0
	RA1 - VREF INP		0
	RA0 - PGD FREE		0

	RC5 - SETUP SW		0
	RC4 - LED DRV		1
	RC3 - SYS PWR		0
	RC2	- VBAT INP		0
	RC1 - KTY81 INP		0
	RC0 - EXT ANL INP	0

	*/

    PORTA = 0b000000001;
    PORTC = 0b000010000;

    setup_timer_0( RTCC_INTERNAL );
    setup_wdt( WDT_TIMES_128);
    set_timer0( T0_LOAD );
    setup_adc(ADC_CLOCK_INTERNAL);

    //Enable interrupts
    enable_interrupts(INT_TIMER0);
    enable_interrupts(GLOBAL);
}



void read_ADCvolts(char *_rp)
{  // Note: requires re-write to access all used analog channels now

    int i;
    long acum=0;
    int ADC_LUT[]={4,5,6};

    ADCON0 = 0b11000001;    // SET VREF = LM385
    set_adc_channel(ADC_LUT[0]);
    ADC_WAIT
    analogs[0] = read_adc();

    set_adc_channel(ADC_LUT[2]);
    ADC_WAIT
    analogs[2] = read_adc();

    // Read digital pin voltage to allow for voltage drop of PIC
    ADCON0 = 0b10000001;    // SET VREF = VDD
    set_adc_channel(7);
    ADC_WAIT
    analogs[3] = read_adc();

    set_adc_channel(ADC_LUT[1]);
    for(i=0;i<64;i++)
    {
        START_ADC_CONVERSION
        ADC_WAIT
        acum += read_adc();
    }
    analogs[1] = acum;
}


